@@ -14,7 +14,7 @@ pub fn parse_yaml_header(text: &str) -> Option<YamlHeader> {
   while scanner.has_next() {
     if scanner.is_next_text("---") {
       scanner.move_text("---");
-      if scanner.move_new_line() {
+      if scanner.move_new_line() || scanner.pos() == scanner.end() {
         let range = std::ops::Range { start: 0, end: scanner.pos() };
         let header_text = String::from(&text[range.start..range.end]);
         return Some(YamlHeader { range, text: header_text });
@@ -26,3 +26,22 @@ pub fn parse_yaml_header(text: &str) -> Option<YamlHeader> {
 
   return None;
 }
+
+#[cfg(test)]
+mod test {
+  use super::*;
+  #[test]
+  fn it_should_parse_yaml_header() {
+    let result = parse_yaml_header(
+      r#"---
+a: b
+---
+
+Test"#,
+    )
+    .unwrap();
+
+    assert_eq!(result.range.start, 0);
+    assert_eq!(result.range.end, 12);
+  }
+}
