@@ -12,7 +12,7 @@ use dprint_plugin_markdown::*;
 #[test]
 fn test_specs() {
   //debug_here!();
-  let global_config = resolve_global_config(HashMap::new()).config;
+  let global_config = resolve_global_config(HashMap::new(), &Default::default()).config;
 
   run_specs(
     &PathBuf::from("./tests/specs"),
